[![Build Status](https://travis-ci.org/pyviz/nbsite.svg?branch=master)](https://travis-ci.org/pyviz/nbsite)

# NBSite

**Build a tested, sphinx-based website from notebooks**

This project is currently an early work in progress. See the
documentation at [nbsite.pyviz.org](https://nbsite.pyviz.org) for
more information.

Developers can see the latest dev release's docs at
https://ioam-docs.github.io/nbsite-dev/
